.. include:: links.rst
.. include:: ../README.rst
   :end-line: 29
.. include:: ../README.rst
   :start-line: 34


.. image:: _static/eddymotion-flowchart.svg
   :alt: The eddymotion flowchart

Contents
--------
.. toctree::
    :maxdepth: 3

    installation
    running
    developers
    changes
